@@ -1,10 +1,13 @@
 #!/usr/bin/env python
 import json
+import sys
 import logging
 import requests
 import socket
 import pandas as pd
 
+sys.tracebacklimit = None
+
 logger = logging.getLogger(__name__)
 
 HOST_IP = socket.gethostbyname(socket.gethostname())
@@ -56,16 +59,16 @@ class AthenaClient:
                 return response
         except requests.exceptions.HTTPError as err_h:
             # logger.error(msg=err_h)
-            raise Exception("Http error occurred")
+            raise Exception("Http error occurred") from None
         except requests.exceptions.ConnectionError as err_c:
             # logger.error(msg=err_c)
-            raise ConnectionError("Connection error occurred")
+            raise ConnectionError("Connection error occurred") from None
         except requests.exceptions.Timeout as err_t:
             # logger.error(msg=err_t)
-            raise TimeoutError("Request timed out...")
+            raise TimeoutError("Request timed out...") from None
         except requests.exceptions.RequestException as err:
             # logger.error(msg=err)
-            raise Exception("RequestException occurred")
+            raise Exception("RequestException occurred") from None
 
     def tables(self, schema_name, result_as_df=True):
         """Returns all the tables present in a schema"""
